@@ -6,7 +6,7 @@ using namespace Rcpp;
 NumericVector computePS(NumericMatrix D, int homDim, NumericVector scaleSeq,int p){
   int n_rows = 0; // number of rows with the correct dimension
   for(int i=0;i<D.nrow();++i){
-    if((D(i,0) == homDim)&(Rcpp::traits::is_finite<REALSXP>(D(i,2)))){
+    if((D(i,0) == homDim) && (Rcpp::traits::is_finite<REALSXP>(D(i,2)))){
       ++n_rows; 
     }
   }
@@ -17,7 +17,7 @@ NumericVector computePS(NumericMatrix D, int homDim, NumericVector scaleSeq,int
   NumericVector x(n_rows),y(n_rows);
   int n=0;
   for(int i=0;i<D.nrow();++i){
-    if((D(i,0) == homDim)&(Rcpp::traits::is_finite<REALSXP>(D(i,2)))){
+    if((D(i,0) == homDim) && (Rcpp::traits::is_finite<REALSXP>(D(i,2)))){
       x[n] = D(i,1);
       y[n] = D(i,2);
       ++n;
